// Copyright (c) 2013 by István Váradi

// This file is part of XPLRA, a remote-access plugin for X-Plane

// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:

// 1. Redistributions of source code must retain the above copyright notice, this
//    list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright notice,
//    this list of conditions and the following disclaimer in the documentation
//    and/or other materials provided with the distribution.

// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// The views and conclusions contained in the software and documentation are those
// of the authors and should not be interpreted as representing official policies,
// either expressed or implied, of the FreeBSD Project.

//------------------------------------------------------------------------------

#include <hu/varadiistvan/xplra/XPlane.h>

#include <cstdio>

//------------------------------------------------------------------------------

using hu::varadiistvan::xplra::XPlane;
using hu::varadiistvan::xplra::Exception;
using hu::varadiistvan::xplra::ProtocolException;

//------------------------------------------------------------------------------

int main()
{
    try {
        XPlane xplane;

        printf("Connecting to X-Plane...\n");
        xplane.connect();
        printf("Connected to X-Plane.\n\n");

        printf("Querying the number of the engines...\n");
        int numEngines = xplane.getInt("sim/aircraft/engine/acf_num_engines");
        printf("The number of engines: %d\n\n", numEngines);

        try {
            printf("Querying an invalid dataref...\n");
            xplane.getInt("sim/aircraft/engine/num_engines");
            printf("\n>>>>>>>>>>>> Succeeded!!!!!!!!!!!!!!!!!!!!!!\n\n");
        } catch(const ProtocolException& exception) {
            printf("Exception caugth: %s\n\n", exception.what());
        }

        printf("Querying the spool time of a jet engine...\n");
        float spoolTime = xplane.getFloat("sim/aircraft/engine/acf_spooltime_jet");
        printf("The spool time: %f\n\n", spoolTime);

        printf("Querying the spool time of a propeller...\n");
        spoolTime = xplane.getFloat("sim/aircraft/engine/acf_spooltime_prop");
        printf("The spool time: %f\n\n", spoolTime);

        printf("Querying the coordinates...\n");
        double latitude = xplane.getDouble("sim/flightmodel/position/latitude");
        double longitude = xplane.getDouble("sim/flightmodel/position/longitude");
        printf("The coordinates: %f, %f\n\n", latitude, longitude);

        return 0;
    } catch(const Exception& exception) {
        printf("\n>>>>>>>>>>>>>>>>> Exception caugth: %s\n", exception.what());

        return 1;
    }
}

//------------------------------------------------------------------------------

// Local Variables:
// mode: C++
// c-basic-offset: 4
// indent-tabs-mode: nil
// End:
